@@ -125,7 +125,7 @@ public class KogitoScenarioSimulationBuilder {
         JsUtils.setNameOnWrapped(scesim, makeJSINameForSCESIM());
         JsUtils.setValueOnWrapped(scesim, jsiScenarioSimulationModelType);
         SCESIMMarshallCallback scesimMarshallCallback = getSCESIMMarshallCallback(callback);
-        SCESIMMainJs.marshall(scesim, "", scesimMarshallCallback);
+        SCESIMMainJs.marshall(scesim, null, scesimMarshallCallback);
     }
 
     private JSIName makeJSINameForSCESIM() {
@@ -379,25 +379,23 @@ public class KogitoScenarioSimulationBuilder {
         List<String> previousSteps = new ArrayList<>(readOnlyPreviousSteps);
         // if is a simple type it generates a single column
         if (factModelTree.isSimple()) {
-
-            String factType = factModelTree.getSimpleProperties().get(VALUE);
-            factMappingExtractor.getFactMapping(factModelTree, VALUE, previousSteps, factType);
+            FactModelTree.PropertyTypeName factType = factModelTree.getSimpleProperties().get(VALUE);
+            factMappingExtractor.getFactMapping(factModelTree, VALUE, previousSteps, factType.getTypeName());
         }
         // otherwise it adds a column for each simple properties direct or nested
         else {
-            for (Map.Entry<String, String> entry : factModelTree.getSimpleProperties().entrySet()) {
+            factModelTree.getSimpleProperties().entrySet().stream().sorted(Map.Entry.comparingByKey()).forEach(entry -> {
                 String factName = entry.getKey();
-                String factType = entry.getValue();
+                String factTypeName = entry.getValue().getTypeName();
 
-                FactMapping factMapping = factMappingExtractor.getFactMapping(factModelTree, factName, previousSteps, factType);
-
-                if (ScenarioSimulationSharedUtils.isList(factType)) {
+                FactMapping factMapping = factMappingExtractor.getFactMapping(factModelTree, factName, previousSteps, factTypeName);
+                if (ScenarioSimulationSharedUtils.isList(factTypeName)) {
                     factMapping.setGenericTypes(factModelTree.getGenericTypeInfo(factName));
                 }
-                factMapping.addExpressionElement(factName, factType);
-            }
+                factMapping.addExpressionElement(factName, factTypeName);
+           });
 
-            for (Map.Entry<String, String> entry : factModelTree.getExpandableProperties().entrySet()) {
+            factModelTree.getExpandableProperties().entrySet().stream().sorted(Map.Entry.comparingByValue()).forEach(entry -> {
                 String factType = entry.getValue();
                 FactModelTree nestedModelTree = hiddenValues.get(factType);
 
@@ -412,7 +410,7 @@ public class KogitoScenarioSimulationBuilder {
                     alreadyVisited.add(factModelTree.getFactName());
                     internalAddToScenario(factMappingExtractor, nestedModelTree, currentSteps, hiddenValues, alreadyVisited);
                 }
-            }
+            });
         }
     }
 
